@@ -1,23 +1,16 @@
 package Crypt::OpenSSL::PKCS12;
 
 use strict;
-use vars qw($VERSION @EXPORT_OK);
 use Exporter;
-use base qw(Exporter);
 
-$VERSION = '1.0';
+our $VERSION = '1.1';
+our @ISA = qw(Exporter);
 
-@EXPORT_OK = qw(NOKEYS NOCERTS INFO CLCERTS CACERTS);
+our @EXPORT_OK = qw(NOKEYS NOCERTS INFO CLCERTS CACERTS);
 
-BOOT_XS: {
-  require DynaLoader;
+use XSLoader;
 
-  # DynaLoader calls dl_load_flags as a static method.
-  *dl_load_flags = DynaLoader->can('dl_load_flags');
-
-  do {__PACKAGE__->can('bootstrap') ||
-    \&DynaLoader::bootstrap}->(__PACKAGE__,$VERSION);
-}
+XSLoader::load 'Crypt::OpenSSL::PKCS12', $VERSION;
 
 END {
   __PACKAGE__->__PKCS12_cleanup();
